- align result Icons better on test tree
- some form of result viewer
    -
- search by name/tag functionality
- menu dynamic plugin installation+flags (needs uv)
- using something like watchfiles to detect filechanges and update the test_tree accordingly (or just stick with a manual refresh)
